pub struct DbcSpec {
pub alias: String,
pub path: String,
}Fields
alias: Stringpath: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for DbcSpec
impl<'de> Deserialize<'de> for DbcSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DbcSpec
impl JsonSchema for DbcSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for DbcSpec
impl Ord for DbcSpec
Sourceimpl PartialOrd for DbcSpec
impl PartialOrd for DbcSpec
impl Eq for DbcSpec
impl StructuralPartialEq for DbcSpec