pub struct DecodedSignalValue {
pub name: String,
pub value: f64,
pub unit: Option<String>,
}Fields
name: Stringvalue: f64unit: Option<String>Trait Implementations
Sourceimpl Clone for DecodedSignalValue
impl Clone for DecodedSignalValue
Sourcefn clone(&self) -> DecodedSignalValue
fn clone(&self) -> DecodedSignalValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecodedSignalValue
impl Debug for DecodedSignalValue
Sourceimpl<'de> Deserialize<'de> for DecodedSignalValue
impl<'de> Deserialize<'de> for DecodedSignalValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecodedSignalValue
impl JsonSchema for DecodedSignalValue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DecodedSignalValue
impl RefUnwindSafe for DecodedSignalValue
impl Send for DecodedSignalValue
impl Sync for DecodedSignalValue
impl Unpin for DecodedSignalValue
impl UnsafeUnpin for DecodedSignalValue
impl UnwindSafe for DecodedSignalValue