pub struct MessageListEntry {
pub label: String,
pub kind: MessageEntryKind,
pub arb_id: u32,
pub extended: bool,
pub fd: bool,
pub len: u8,
pub last_seen_unix_ms: u128,
pub has_rx: bool,
pub has_tx: bool,
}Fields
label: Stringkind: MessageEntryKindarb_id: u32extended: boolfd: boollen: u8last_seen_unix_ms: u128has_rx: boolhas_tx: boolTrait Implementations
Sourceimpl Clone for MessageListEntry
impl Clone for MessageListEntry
Sourcefn clone(&self) -> MessageListEntry
fn clone(&self) -> MessageListEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageListEntry
impl Debug for MessageListEntry
Sourceimpl<'de> Deserialize<'de> for MessageListEntry
impl<'de> Deserialize<'de> for MessageListEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageListEntry
impl JsonSchema for MessageListEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MessageListEntry
impl RefUnwindSafe for MessageListEntry
impl Send for MessageListEntry
impl Sync for MessageListEntry
impl Unpin for MessageListEntry
impl UnsafeUnpin for MessageListEntry
impl UnwindSafe for MessageListEntry