pub struct MessageStopRequest {
pub target: String,
}Fields
target: StringTrait Implementations
Sourceimpl Clone for MessageStopRequest
impl Clone for MessageStopRequest
Sourcefn clone(&self) -> MessageStopRequest
fn clone(&self) -> MessageStopRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageStopRequest
impl Debug for MessageStopRequest
Sourceimpl<'de> Deserialize<'de> for MessageStopRequest
impl<'de> Deserialize<'de> for MessageStopRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageStopRequest
impl JsonSchema for MessageStopRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MessageStopRequest
impl PartialEq for MessageStopRequest
Sourceimpl Serialize for MessageStopRequest
impl Serialize for MessageStopRequest
impl Eq for MessageStopRequest
impl StructuralPartialEq for MessageStopRequest