pub struct PeriodicSchedule {
pub target: String,
pub arb_id: u32,
pub extended: bool,
pub fd: bool,
pub len: u8,
pub periodicity_ms: u64,
}Fields
target: Stringarb_id: u32extended: boolfd: boollen: u8periodicity_ms: u64Trait Implementations
Sourceimpl Clone for PeriodicSchedule
impl Clone for PeriodicSchedule
Sourcefn clone(&self) -> PeriodicSchedule
fn clone(&self) -> PeriodicSchedule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeriodicSchedule
impl Debug for PeriodicSchedule
Sourceimpl<'de> Deserialize<'de> for PeriodicSchedule
impl<'de> Deserialize<'de> for PeriodicSchedule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PeriodicSchedule
impl JsonSchema for PeriodicSchedule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PeriodicSchedule
impl RefUnwindSafe for PeriodicSchedule
impl Send for PeriodicSchedule
impl Sync for PeriodicSchedule
impl Unpin for PeriodicSchedule
impl UnsafeUnpin for PeriodicSchedule
impl UnwindSafe for PeriodicSchedule