pub struct SchemaSignal {
pub name: String,
pub value_type: String,
pub unit: Option<String>,
pub min: Option<f64>,
pub max: Option<f64>,
pub factor: f64,
pub offset: f64,
pub start_bit: u64,
pub bit_len: u64,
}Fields
name: Stringvalue_type: Stringunit: Option<String>min: Option<f64>max: Option<f64>factor: f64offset: f64start_bit: u64bit_len: u64Trait Implementations
Sourceimpl Clone for SchemaSignal
impl Clone for SchemaSignal
Sourcefn clone(&self) -> SchemaSignal
fn clone(&self) -> SchemaSignal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaSignal
impl Debug for SchemaSignal
Sourceimpl<'de> Deserialize<'de> for SchemaSignal
impl<'de> Deserialize<'de> for SchemaSignal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SchemaSignal
impl JsonSchema for SchemaSignal
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SchemaSignal
impl RefUnwindSafe for SchemaSignal
impl Send for SchemaSignal
impl Sync for SchemaSignal
impl Unpin for SchemaSignal
impl UnsafeUnpin for SchemaSignal
impl UnwindSafe for SchemaSignal