pub struct SessionStatus {
pub connection_state: String,
pub adapter: String,
pub bitrate: u32,
pub bitrate_data: Option<u32>,
pub fd: bool,
pub dbcs: Vec<LoadedDbc>,
pub trace_path: Option<String>,
pub periodic_schedules: Vec<PeriodicSchedule>,
pub backend_error: Option<String>,
pub retention_window_secs: u64,
pub retention_event_cap: usize,
}Fields
connection_state: Stringadapter: Stringbitrate: u32bitrate_data: Option<u32>fd: booldbcs: Vec<LoadedDbc>trace_path: Option<String>periodic_schedules: Vec<PeriodicSchedule>backend_error: Option<String>retention_window_secs: u64retention_event_cap: usizeTrait Implementations
Sourceimpl Clone for SessionStatus
impl Clone for SessionStatus
Sourcefn clone(&self) -> SessionStatus
fn clone(&self) -> SessionStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionStatus
impl Debug for SessionStatus
Sourceimpl<'de> Deserialize<'de> for SessionStatus
impl<'de> Deserialize<'de> for SessionStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionStatus
impl JsonSchema for SessionStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionStatus
impl RefUnwindSafe for SessionStatus
impl Send for SessionStatus
impl Sync for SessionStatus
impl Unpin for SessionStatus
impl UnsafeUnpin for SessionStatus
impl UnwindSafe for SessionStatus